@@ -4,7 +4,15 @@ use strict;
 use warnings;
 use Carp;
 
-# methods
+sub die_with_error {
+    my $self = shift;
+    if (my ($code, $name) = $self->error) {
+        die join(": ", @_, "SFTP error $code $name");
+    }
+    else {
+        die join(": ", @_, "no SFTP error registered");
+    }
+}
 
 
 1;
@@ -24,6 +32,11 @@ Returns the last SFTP error (one of the LIBSSH2_FX_* constants).  Use this
 when Net::SSH2::error returns LIBSSH2_ERROR_SFTP_PROTOCOL.  In list context,
 returns (code, error name).
 
+=head2 die_with_error( [message] )
+
+Calls C<die> with the given message and the error information from the
+object appended.
+
 =head2 open ( file [, flags [, mode ]]] )
 
 Open or create a file on the remote host.  The flags are the standard O_RDONLY,
@@ -94,6 +107,10 @@ Resolve a filename's path; returns the resolved path, or undef on error.
 
 L<Net::SSH2>.
 
+Check L<Net::SFTP::Foreign> for a high level, perlish and easy to use
+SFTP client module. It can work on top of Net::SSH2 via the
+L<Net::SFTP::Foreign::Backend::Net_SSH2> backend module.
+
 =head1 AUTHOR
 
 David B. Robins, E<lt>dbrobins@cpan.orgE<gt>
